library(ggplot2)
library(gridExtra)
library(ssh)
setwd("/.../")


####################################################################
####################### DATA PREPARATION ###########################
####################################################################

### READ DATA AND CREATE DATAFRAMES
IO<-read.csv(file="results_tunning_IO.csv",header=TRUE,sep=";")
xLOLIB<-read.csv(file="results_tunning_xLOLIB.csv",header=TRUE,sep=";")
data<-rbind(IO,xLOLIB)
colnames(data)<-c("Instance", "Repetition","Setting", "Lambda", "Alpha","F","Evals","Time")
data<-data[
  with(data, order(Setting, Lambda, Alpha, Instance)),
]
data$Lambda<-as.integer(data$Lambda)
data$Alpha<-as.numeric(data$Alpha)


# Normalize F
results_bks<-read.csv(file="best_known_results.csv",header=TRUE,sep=";",stringsAsFactor=FALSE)
Normalized= seq(1,length(data$Instance),1)
Size=seq(1,length(data$Instance),1)
data = cbind(data,Normalized)
data = cbind(data,Size)
#Performance results comparison
colnames(data)<-c("Instance","Repetition","Setting","Lambda", "Alpha", "F","Evals","Time", "Normalized", "Size")
for (i in 1:length(data$Instance)) 
{
  best_known<-results_bks[results_bks$Instance==data$Instance[i],]
  best_fit<-as.numeric(as.character(best_known$Result))
  fitness<-data[i,]$F
  data[i,]$Normalized<-round(abs(fitness-best_fit)/best_fit,digits = 5)
  data[i,]$Size<-results_bks[results_bks$Instance==data$Instance[i],]$Size
}
data$Repetition<-as.integer(data$Repetition)
data$Size<-as.character(data$Size)

data_IO <- data[grep("_", data$Instance, invert = TRUE), ]
data_xLOLIB_150 <- data[grep("_150", data$Instance, invert = FALSE), ]
data_xLOLIB_250 <- data[grep("_250", data$Instance, invert = FALSE), ]

data_IO_avg<-aggregate(data_IO[, 6:9], list(data_IO$Setting, data_IO$Lambda, data_IO$Alpha), mean)
colnames(data_IO_avg)<-c("Setting", "Lambda", "Alpha","F","Evals","Time", "Normalized")

data_IO_avg$Alpha<-as.factor(data_IO_avg$Alpha)



####################################################################
######################### SCATTER PLOTS ############################
####################################################################

scatterGS_IO<-ggplot(data_IO[data_IO$Setting=="PL",], aes(Time, Normalized, color=Alpha, shape=as.factor(Lambda), alpha=0.3)) + 
  geom_point(size=2)+
  scale_color_gradient(low="cornflowerblue", high="coral2",breaks=c(0.001, 0.01, 0.05, 0.1, 0.5, 0.75, 0.9),labels=c("0.001", "0.01", "0.05", "0.1", "0.5", "0.75", "0.9"),limits=c(0.001,0.9))+
  labs(x="Execution Time (s)", y="Relative deviation", col="\u03B7", shape="\u03BB")+ 
   ggtitle(label = "GS - IO")+
  guides(alpha = "none", colour = guide_legend(override.aes = list(size = 3), order = 1))+
  ylim(min(data_IO$Normalized), max(data_IO$Normalized))+
  theme(legend.position="right", legend.box = "horizonal",axis.text = element_text(size = 11), 
        panel.background = element_rect(fill="white"),panel.grid = element_line(color = "grey",
                                                                                size = 0.2,
                                                                                linetype = 1),
        panel.border = element_rect(colour = "black", fill=NA, size=0.5))

scatterNES_IO<- ggplot(data_IO[data_IO$Setting=="PLN",], aes(Time, Normalized, color=Alpha, shape=as.factor(Lambda), alpha=0.3)) + 
  geom_point(size=2)+
  scale_color_gradient(low="cornflowerblue", high="coral2",breaks=c(0.001, 0.01, 0.05, 0.1, 0.5, 0.75, 0.9),labels=c("0.001", "0.01", "0.05", "0.1", "0.5", "0.75", "0.9"),limits=c(0.001,0.9))+
  labs(x="Execution Time (s)", y="Relative deviation", col="\u03B7", shape="\u03BB")+ 
  ggtitle(label = "NES - IO")+
  guides(alpha = "none", colour = guide_legend(override.aes = list(size = 3), order = 1))+
  ylim(min(data_IO$Normalized), max(data_IO$Normalized))+
  theme(legend.position="right", legend.box = "horizonal",axis.text = element_text(size = 11), 
        panel.background = element_rect(fill="white"),panel.grid = element_line(color = "grey",
                                                                                size = 0.2,
                                                                                linetype = 1),
        panel.border = element_rect(colour = "black", fill=NA, size=0.5))

scatterNES_xLOLIB_150<- ggplot(data_xLOLIB_150[data_xLOLIB_150$Setting=="PLN",], aes(Time, Normalized, color=Alpha, shape=as.factor(Lambda), alpha=0.3)) + 
  geom_point(size=2)+
  scale_color_gradient(low="cornflowerblue", high="coral2",breaks=c(0.001, 0.01, 0.05, 0.1, 0.5, 0.75, 0.9),labels=c("0.001", "0.01", "0.05", "0.1", "0.5", "0.75", "0.9"),limits=c(0.001,0.9))+
  labs(x="Execution Time (s)", y="Relative deviation", col="\u03B7", shape="\u03BB")+ 
  ggtitle(label = "NES - xLOLIB (n=150)")+
  guides(alpha = "none", colour = guide_legend(override.aes = list(size = 3), order = 1))+
  ylim(min(data_xLOLIB_150$Normalized), max(data_xLOLIB_150$Normalized))+
  theme(legend.position="right", legend.box = "horizonal",axis.text = element_text(size = 11), 
        panel.background = element_rect(fill="white"),panel.grid = element_line(color = "grey",
                                                                                size = 0.2,
                                                                                linetype = 1),
        panel.border = element_rect(colour = "black", fill=NA, size=0.5))

scatterGS_xLOLIB_150<- ggplot(data_xLOLIB_150[data_xLOLIB_150$Setting=="PL",], aes(Time, Normalized, color=Alpha, shape=as.factor(Lambda), alpha=0.3)) + 
  geom_point(size=2)+
  scale_color_gradient(low="cornflowerblue", high="coral2",breaks=c(0.001, 0.01, 0.05, 0.1, 0.5, 0.75, 0.9),labels=c("0.001", "0.01", "0.05", "0.1", "0.5", "0.75", "0.9"),limits=c(0.001,0.9))+
  labs(x="Execution Time (s)", y="Relative deviation", col="\u03B7", shape="\u03BB")+ 
  ggtitle(label = "GS - xLOLIB (n=150)")+
  guides(alpha = "none", colour = guide_legend(override.aes = list(size = 3), order = 1))+
  ylim(min(data_xLOLIB_150$Normalized), max(data_xLOLIB_150$Normalized))+
  theme(legend.position="right", legend.box = "horizonal",axis.text = element_text(size = 11), 
        panel.background = element_rect(fill="white"),panel.grid = element_line(color = "grey", size = 0.2,linetype = 1),
        panel.border = element_rect(colour = "black", fill=NA, size=0.5))


scatterNES_xLOLIB_250<- ggplot(data_xLOLIB_250[data_xLOLIB_250$Setting=="PLN",], aes(Time, Normalized, color=Alpha, shape=as.factor(Lambda), alpha=0.3)) + 
  geom_point(size=2)+
  scale_color_gradient(low="cornflowerblue", high="coral2",breaks=c(0.001, 0.01, 0.05, 0.1, 0.5, 0.75, 0.9),labels=c("0.001", "0.01", "0.05", "0.1", "0.5", "0.75", "0.9"),limits=c(0.001,0.9))+
  labs(x="Execution Time (s)", y="Relative deviation", col="\u03B7", shape="\u03BB")+ 
  ggtitle(label = "NES - xLOLIB (n=250)")+
  guides(alpha = "none", colour = guide_legend(override.aes = list(size = 3), order = 1))+
  ylim(min(data_xLOLIB_250$Normalized), max(data_xLOLIB_250$Normalized))+
  theme(legend.position="right", legend.box = "horizonal",axis.text = element_text(size = 11), 
        panel.background = element_rect(fill="white"),panel.grid = element_line(color = "grey", size = 0.2,linetype = 1),
        panel.border = element_rect(colour = "black", fill=NA, size=0.5))

scatterGS_xLOLIB_250<- ggplot(data_xLOLIB_250[data_xLOLIB_250$Setting=="PL",], aes(Time, Normalized, color=Alpha, shape=as.factor(Lambda), alpha=0.3)) + 
  geom_point(size=2)+
  scale_color_gradient(low="cornflowerblue", high="coral2",breaks=c(0.001, 0.01, 0.05, 0.1, 0.5, 0.75, 0.9),labels=c("0.001", "0.01", "0.05", "0.1", "0.5", "0.75", "0.9"),limits=c(0.001,0.9))+
  labs(x="Execution Time (s)", y="Relative deviation", col="\u03B7", shape="\u03BB")+ 
  ggtitle(label = "GS - xLOLIB (n=250)")+
  guides(alpha = "none", colour = guide_legend(override.aes = list(size = 3), order = 1))+
  ylim(min(data_xLOLIB_250$Normalized), max(data_xLOLIB_250$Normalized))+
  theme(legend.position="right", legend.box = "horizonal",axis.text = element_text(size = 11), 
        panel.background = element_rect(fill="white"),panel.grid = element_line(color = "grey", size = 0.2,linetype = 1),
        panel.border = element_rect(colour = "black", fill=NA, size=0.5))

scatter_IO<-grid.arrange(scatterGS_IO,scatterGS_xLOLIB_150,scatterGS_xLOLIB_250,scatterNES_IO,scatterNES_xLOLIB_150,scatterNES_xLOLIB_250, nrow=2, ncol=3)
ggsave("tunning_scatter_IO_xLOLIB.png",scatter_IO, width = 300, height = 200, dpi = 400, units = "mm", device='png')

####################################################################
######################### HEATMAP PLOTS ############################
####################################################################

 # Heatmaps - IO:
data_IO_avg$Lambda <- as.factor(data_IO_avg$Lambda)
data_IO_avg$Alpha <- as.factor(data_IO_avg$Alpha)
data_IO_avg$Normalized<-round(data_IO_avg$Normalized,digits = 5)

heatmapGS_IO<- ggplot(data_IO_avg[data_IO_avg$Setting=="PL",], aes(Lambda, Alpha, fill= Normalized)) + 
  geom_tile() +
  geom_text(aes(label = Normalized), color = "black", size = 4) +
  guides(fill="none")+
  ggtitle(label = "Gradient Search - IO") + scale_fill_gradient(low = "steelblue", high = "white",trans = "log",limits=c(min(data_IO_avg$Normalized),max(data_IO_avg$Normalized)))+
  theme(axis.text = element_text(size = 12))  

heatmapsNES_IO<- ggplot(data_IO_avg[data_IO_avg$Setting=="PLN",], aes(Lambda, Alpha, fill= Normalized)) + 
  geom_tile() +
  geom_text(aes(label = Normalized), color = "black", size = 4) +
  labs(fill="MDR")+
  ggtitle(label = "Natural Evolution Strategy - IO") + scale_fill_gradient(low = "steelblue", high = "white",trans = "log", limits=c(min(data_IO_avg$Normalized),max(data_IO_avg$Normalized)))+
  theme(axis.text = element_text(size = 12))  

heatmaps_IO<-grid.arrange(heatmapGS_IO,heatmapsNES_IO, ncol=2)
ggsave("tunning_heatmaps_IO.png",heatmaps_IO, width = 300, height = 100, dpi = 400, units = "mm", device='png')

# Heatmaps - xLOLIB:

####### n=150
data_xLOLIB_150_avg<-aggregate(data_xLOLIB_150[, 6:9], list(data_xLOLIB_150$Setting, data_xLOLIB_150$Lambda, data_xLOLIB_150$Alpha), mean)
colnames(data_xLOLIB_150_avg)<-c("Setting", "Lambda", "Alpha","F","Evals","Time", "Normalized")

data_xLOLIB_150_avg$Lambda <- as.factor(data_xLOLIB_150_avg$Lambda)
data_xLOLIB_150_avg$Alpha <- as.factor(data_xLOLIB_150_avg$Alpha)
data_xLOLIB_150_avg$Normalized<-round(data_xLOLIB_150_avg$Normalized,digits = 5)

heatmapGS_xLOLIB_150<- ggplot(data_xLOLIB_150_avg[data_xLOLIB_150_avg$Setting=="PL",], aes(Lambda, Alpha, fill= Normalized)) + 
  geom_tile() +
  geom_text(aes(label = Normalized), color = "black", size = 4) +
  guides(fill="none")+
  ggtitle(label = "Gradient Search - xLOLIB (n=150)") + scale_fill_gradient(low = "steelblue", high = "white",trans = "log",limits=c(min(data_xLOLIB_150_avg$Normalized),max(data_xLOLIB_150_avg$Normalized)))+
  theme(axis.text = element_text(size = 12))  

heatmapNES_xLOLIB_150<- ggplot(data_xLOLIB_150_avg[data_xLOLIB_150_avg$Setting=="PLN",], aes(Lambda, Alpha, fill= Normalized)) + 
  geom_tile() +
  geom_text(aes(label = Normalized), color = "black", size = 4) +
  labs(fill="MDR")+
  ggtitle(label = "Natural Evolution Strategy - xLOLIB (n=150)") + scale_fill_gradient(low = "steelblue", high = "white",trans = "log", limits=c(min(data_xLOLIB_150_avg$Normalized),max(data_xLOLIB_150_avg$Normalized)))+
  theme(axis.text = element_text(size = 12))  

####### n=250
data_xLOLIB_250_avg<-aggregate(data_xLOLIB_250[, 6:9], list(data_xLOLIB_250$Setting, data_xLOLIB_250$Lambda, data_xLOLIB_250$Alpha), mean)
colnames(data_xLOLIB_250_avg)<-c("Setting", "Lambda", "Alpha","F","Evals","Time", "Normalized")

data_xLOLIB_250_avg$Lambda <- as.factor(data_xLOLIB_250_avg$Lambda)
data_xLOLIB_250_avg$Alpha <- as.factor(data_xLOLIB_250_avg$Alpha)
data_xLOLIB_250_avg$Normalized<-round(data_xLOLIB_250_avg$Normalized,digits = 5)

heatmapGS_xLOLIB_250<- ggplot(data_xLOLIB_250_avg[data_xLOLIB_250_avg$Setting=="PL",], aes(Lambda, Alpha, fill= Normalized)) + 
  geom_tile() +
  geom_text(aes(label = Normalized), color = "black", size = 4) +
  guides(fill="none")+
  ggtitle(label = "Gradient Search - xLOLIB (n=250)") + scale_fill_gradient(low = "steelblue", high = "white",trans = "log",limits=c(min(data_xLOLIB_250_avg$Normalized),max(data_xLOLIB_250_avg$Normalized)))+
  theme(axis.text = element_text(size = 12))  

heatmapNES_xLOLIB_250<- ggplot(data_xLOLIB_250_avg[data_xLOLIB_250_avg$Setting=="PLN",], aes(Lambda, Alpha, fill= Normalized)) + 
  geom_tile() +
  geom_text(aes(label = Normalized), color = "black", size = 4) +
  labs(fill="MDR")+
  ggtitle(label = "Natural Evolution Strategy - xLOLIB (n=250)") + scale_fill_gradient(low = "steelblue", high = "white",trans = "log", limits=c(min(data_xLOLIB_250_avg$Normalized),max(data_xLOLIB_250_avg$Normalized)))+
  theme(axis.text = element_text(size = 12))  

heatmaps_IO<-grid.arrange(heatmapGS_xLOLIB_150,heatmapNES_xLOLIB_150, heatmapGS_xLOLIB_250, heatmapNES_xLOLIB_250, nrow=2, ncol=2)
ggsave("tunning_heatmaps_xLOLIB.png",heatmaps_IO, width = 300, height = 200, dpi = 400, units = "mm", device='png')

############################################################################
################### BAYESIAN CREDIBLE INTERVALS ############################
############################################################################

# BAYESIAN Credible Interval Plots
getCredibleIntervalsWeights <- function(posterior.samples, interval.size=0.9) {
  qmin <- (1-interval.size)/2
  qmax <- 1-qmin
  lower.bound <- apply(posterior.samples, MARGIN=2, FUN=quantile, p=qmin) 
  upper.bound <- apply(posterior.samples, MARGIN=2, FUN=quantile, p=qmax) 
  expectation <- apply(posterior.samples, MARGIN=2, FUN=mean) 
  return (data.frame(Expected=expectation, Lower_bound=lower.bound, Upper_bound=upper.bound))
}
library("scmamp")

## Load data
lambdas_IO<-unique(data_IO$Lambda)
alphas_IO<-unique(data_IO$Alpha)

# BAYESIAN FOR GRADIENT SEARCH IO
dataBayesian_IO <- data.frame(matrix(NA, nrow = 150, ncol = 28))  ## for IO benchmark

col<-1
for (l in lambdas_IO){
  for (a in alphas_IO){
    columnname<-paste("\u03BB",l,"\u03B7",a,collapse="")
    print(columnname)
    values<-data_IO[(data_IO$Lambda==l & data_IO$Alpha==a & data_IO$Setting=="PL"),]$F
    values
    #dataBayesian_IO[,col]<-values
    dataBayesian_IO[,col]<-c(values, rep(NA, nrow(dataBayesian_IO)-length(values)))
    colnames(dataBayesian_IO)[col] <-columnname
    col<-col+1
  }
}


## Statistical Analysis
pl_model <-  bPlackettLuceModel(x.matrix=dataBayesian_IO, min=FALSE, nsim=4000, nchains=20, parallel=TRUE)

## Plot
processed.results <- getCredibleIntervalsWeights(pl_model$posterior.weights, interval.size=0.9)
dataBayesian_IO_2 <- data.frame(Setting=rownames(processed.results), processed.results)
bayesianGS_IO<-ggplot(dataBayesian_IO_2, aes(y=Expected, ymin=Lower_bound, ymax=Upper_bound, x=Setting)) + geom_errorbar() + geom_point(col="darkgreen", size=2) +  theme_bw() + coord_flip() + labs(y="Probability of winning")+ggtitle(label = "GS - IO")

# BAYESIAN for NES IO
dataBayesian_IO <- data.frame(matrix(NA, nrow = 150, ncol = 28))  ## for IO benchmark

col<-1
for (l in lambdas_IO){
  for (a in alphas_IO){
    columnname<-paste("\u03BB",l,"\u03B7",a,collapse="")
    ##print(columnname)
    values<-data_IO[(data_IO$Lambda==l & data_IO$Alpha==a & data_IO$Setting=="PLN"),]$F
    #dataBayesian[,col]<-values
    dataBayesian_IO[,col]<-c(values, rep(NA, nrow(dataBayesian_IO)-length(values)))
    colnames(dataBayesian_IO)[col] <-columnname
    col<-col+1
  }
}


## Statistical Analysis
pl_model <-  bPlackettLuceModel(x.matrix=dataBayesian_IO, min=FALSE, nsim=4000, nchains=20, parallel=TRUE)

## Plot
processed.results <- getCredibleIntervalsWeights(pl_model$posterior.weights, interval.size=0.9)
dataBayesian_IO_2 <- data.frame(Setting=rownames(processed.results), processed.results)
bayesianNES_IO<-ggplot(dataBayesian_IO_2, aes(y=Expected, ymin=Lower_bound, ymax=Upper_bound, x=Setting)) + geom_errorbar() + geom_point(col="darkgreen", size=2) +  theme_bw() + coord_flip() + labs(y="Probability of winning")+ggtitle(label = "NES - IO")

# BAYESIAN for GS xLOLIB n=150

lambdas_xLOLIB<-unique(data_xLOLIB_150$Lambda)
alphas_xLOLIB<-unique(data_xLOLIB_150$Alpha)

dataBayesian_xLOLIB_150 <- data.frame(matrix(NA, nrow = 120, ncol = 28))  ## for IO benchmark

col<-1
for (l in lambdas_xLOLIB){
  for (a in alphas_xLOLIB){
    columnname<-paste("\u03BB",l,"\u03B7",a,collapse="")
    ##print(columnname)
    values<-data_xLOLIB_150[(data_xLOLIB_150$Lambda==l & data_xLOLIB_150$Alpha==a & data_xLOLIB_150$Setting=="PL"),]$F
    #dataBayesian[,col]<-values
    dataBayesian_xLOLIB_150[,col]<-c(values, rep(NA, nrow(dataBayesian_xLOLIB_150)-length(values)))
    colnames(dataBayesian_xLOLIB_150)[col] <-columnname
    col<-col+1
  }
}


## Statistical Analysis
pl_model <-  bPlackettLuceModel(x.matrix=dataBayesian_xLOLIB_150, min=FALSE, nsim=4000, nchains=20, parallel=TRUE)

## Plot
processed.results <- getCredibleIntervalsWeights(pl_model$posterior.weights, interval.size=0.9)
dataBayesian_xLOLIB_150_2 <- data.frame(Setting=rownames(processed.results), processed.results)
bayesianGS_xLOLIB_150<-ggplot(dataBayesian_xLOLIB_150_2, aes(y=Expected, ymin=Lower_bound, ymax=Upper_bound, x=Setting)) + geom_errorbar() + geom_point(col="darkgreen", size=2) +  theme_bw() + coord_flip() + labs(y="Probability of winning")+ggtitle(label = "GS - xLOLIB (n=150)")


# BAYESIAN for NES xLOLIB n=150

lambdas_xLOLIB<-unique(data_xLOLIB_150$Lambda)
alphas_xLOLIB<-unique(data_xLOLIB_150$Alpha)

dataBayesian_xLOLIB_150 <- data.frame(matrix(NA, nrow = 120, ncol = 28))  ## for IO benchmark

col<-1
for (l in lambdas_xLOLIB){
  for (a in alphas_xLOLIB){
    columnname<-paste("\u03BB",l,"\u03B7",a,collapse="")
    ##print(columnname)
    values<-data_xLOLIB_150[(data_xLOLIB_150$Lambda==l & data_xLOLIB_150$Alpha==a & data_xLOLIB_150$Setting=="PLN"),]$F
    #dataBayesian[,col]<-values
    dataBayesian_xLOLIB_150[,col]<-c(values, rep(NA, nrow(dataBayesian_xLOLIB_150)-length(values)))
    colnames(dataBayesian_xLOLIB_150)[col] <-columnname
    col<-col+1
  }
}


## Statistical Analysis
pl_model <-  bPlackettLuceModel(x.matrix=dataBayesian_xLOLIB_150, min=FALSE, nsim=4000, nchains=20, parallel=TRUE)

## Plot
processed.results <- getCredibleIntervalsWeights(pl_model$posterior.weights, interval.size=0.9)
dataBayesian_xLOLIB_150_2 <- data.frame(Setting=rownames(processed.results), processed.results)
bayesianNES_xLOLIB_150<-ggplot(dataBayesian_xLOLIB_150_2, aes(y=Expected, ymin=Lower_bound, ymax=Upper_bound, x=Setting)) + geom_errorbar() + geom_point(col="darkgreen", size=2) +  theme_bw() + coord_flip() + labs(y="Probability of winning")+ggtitle(label = "NES - xLOLIB (n=150)")


# BAYESIAN for GS xLOLIB n=250

lambdas_xLOLIB<-unique(data_xLOLIB_250$Lambda)
alphas_xLOLIB<-unique(data_xLOLIB_250$Alpha)

dataBayesian_xLOLIB_250 <- data.frame(matrix(NA, nrow = 120, ncol = 21))  ## for IO benchmark

col<-1
for (l in lambdas_xLOLIB){
  for (a in alphas_xLOLIB){
    columnname<-paste("\u03BB",l,"\u03B7",a,collapse="")
    ##print(columnname)
    values<-data_xLOLIB_250[(data_xLOLIB_250$Lambda==l & data_xLOLIB_250$Alpha==a & data_xLOLIB_250$Setting=="PL"),]$F
    #dataBayesian[,col]<-values
    dataBayesian_xLOLIB_250[,col]<-c(values, rep(NA, nrow(dataBayesian_xLOLIB_250)-length(values)))
    colnames(dataBayesian_xLOLIB_250)[col] <-columnname
    col<-col+1
  }
}


## Statistical Analysis
pl_model <-  bPlackettLuceModel(x.matrix=dataBayesian_xLOLIB_250, min=FALSE, nsim=4000, nchains=20, parallel=TRUE)

## Plot
processed.results <- getCredibleIntervalsWeights(pl_model$posterior.weights, interval.size=0.9)
dataBayesian_xLOLIB_250_2 <- data.frame(Setting=rownames(processed.results), processed.results)
bayesianGS_xLOLIB_250<-ggplot(dataBayesian_xLOLIB_250_2, aes(y=Expected, ymin=Lower_bound, ymax=Upper_bound, x=Setting)) + geom_errorbar() + geom_point(col="darkgreen", size=2) +  theme_bw() + coord_flip() + labs(y="Probability of winning")+ggtitle(label = "GS - xLOLIB (n=250)")


# BAYESIAN for NES xLOLIB n=250

lambdas_xLOLIB<-unique(data_xLOLIB_250$Lambda)
alphas_xLOLIB<-unique(data_xLOLIB_250$Alpha)

dataBayesian_xLOLIB_250 <- data.frame(matrix(NA, nrow = 120, ncol = 21))  ## for IO benchmark

col<-1
for (l in lambdas_xLOLIB){
  for (a in alphas_xLOLIB){
    columnname<-paste("\u03BB",l,"\u03B7",a,collapse="")
    ##print(columnname)
    values<-data_xLOLIB_250[(data_xLOLIB_250$Lambda==l & data_xLOLIB_250$Alpha==a & data_xLOLIB_250$Setting=="PLN"),]$F
    #dataBayesian[,col]<-values
    dataBayesian_xLOLIB_250[,col]<-c(values, rep(NA, nrow(dataBayesian_xLOLIB_250)-length(values)))
    colnames(dataBayesian_xLOLIB_250)[col] <-columnname
    col<-col+1
  }
}


## Statistical Analysis
pl_model <-  bPlackettLuceModel(x.matrix=dataBayesian_xLOLIB_250, min=FALSE, nsim=4000, nchains=20, parallel=TRUE)

## Plot
processed.results <- getCredibleIntervalsWeights(pl_model$posterior.weights, interval.size=0.9)
dataBayesian_xLOLIB_250_2 <- data.frame(Setting=rownames(processed.results), processed.results)
bayesianNES_xLOLIB_250<-ggplot(dataBayesian_xLOLIB_250_2, aes(y=Expected, ymin=Lower_bound, ymax=Upper_bound, x=Setting)) + geom_errorbar() + geom_point(col="darkgreen", size=2) +  theme_bw() + coord_flip() + labs(y="Probability of winning")+ggtitle(label = "NES - xLOLIB (n=250)")


# PRINT FINAL PLOT
bayesian_IO_xLOLIB<-grid.arrange(bayesianGS_IO,bayesianGS_xLOLIB_150,bayesianGS_xLOLIB_250,bayesianNES_IO,bayesianNES_xLOLIB_150,bayesianNES_xLOLIB_250, nrow=2, ncol=3)
ggsave("tunning_bayesian_IO_xLOLIB.png",bayesian_IO_xLOLIB, width = 300, height = 175, dpi = 400, units = "mm", device='png')


